/*
 * refreshthread.cpp
 *
 * Copyright (c) 2016 Stephane List
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include "refreshthread.h"
#include "conninode.h"
#include "process.h"

#include <QtDebug>

extern ProcList * processes;
extern timeval curtime;
extern Process * unknowntcp;
extern Process * unknownudp;
extern Process * unknownip;

/** get total values for this process */
void gettotal(Process * curproc, u_int32_t * recvd, u_int32_t * sent)
{
    u_int32_t sum_sent = 0, sum_recv = 0;
    ConnList * curconn = curproc->connections;
    while (curconn != NULL)
    {
        Connection * conn = curconn->getVal();
        sum_sent += conn->sumSent;
        sum_recv += conn->sumRecv;
        curconn = curconn->getNext();
    }
    *recvd = sum_recv;
    *sent = sum_sent;
}

void gettotalb(Process * curproc, quint64 * recvd, quint64 * sent)
{
    u_int32_t sum_sent = 0, sum_recv = 0;
    gettotal(curproc, &sum_recv, &sum_sent);
    *sent = sum_sent;
    *recvd = sum_recv;
}

RefreshThread::RefreshThread(QObject *parent) : QThread(parent)
{

}

void RefreshThread::run()
{
    while (1) {
        sleep(1);

        refreshconninode();

        ProcList * curproc = processes;
        ProcList * previousproc = NULL;
        int nproc = processes->size();

        while (curproc != NULL)
        {
            // walk though its connections, summing up their data, and
            // throwing away connections that haven't received a package
            // in the last PROCESSTIMEOUT seconds.
            assert (curproc != NULL);
            assert (curproc->getVal() != NULL);
            assert (nproc == processes->size());

            /* remove timed-out processes (unless it's one of the the unknown process) */
            if ((curproc->getVal()->getLastPacket() + PROCESSTIMEOUT <= curtime.tv_sec)
                    && (curproc->getVal() != unknowntcp)
                    && (curproc->getVal() != unknownudp)
                    && (curproc->getVal() != unknownip))
            {
                //qDebug() << "PROC: Deleting process" << curproc->getVal()->name;
                ProcList * todelete = curproc;
                Process * p_todelete = curproc->getVal();

                emit procDeleted(curproc->getVal()->pid);

                if (previousproc)
                {
                    previousproc->next = curproc->next;
                    curproc = curproc->next;
                } else {
                    processes = curproc->getNext();
                    curproc = processes;
                }
                delete todelete;
                delete p_todelete;
                nproc--;
            }
            else
            {
                // add a non-timed-out process to the list of stuff to show
                quint64 value_sent = 0, value_recv = 0;

                gettotalb(curproc->getVal(), &value_recv, &value_sent);
                uid_t uid = curproc->getVal()->getUid();

                emit procDetected(curproc->getVal()->name, value_recv, value_sent, curproc->getVal()->pid, uid , curproc->getVal()->devicename);;

                previousproc = curproc;
                curproc = curproc->next;
            }
        }
         emit refresh_finished();
    }
}
